==> vue-text-popup-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/text-popup/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "placeholder", "readonly", "width", "separtor"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-text-popup", {
      "show-auto-width": _vm.state.showAutoWidth
    }],
    style: {
      width: !_vm.state.showAutoWidth && _vm.state.width
    }
  }, [_c("input", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.type === "input",
      expression: "state.type === 'input'"
    }],
    ref: "text",
    staticClass: "area text",
    attrs: {
      "placeholder": _vm.placeholder
    },
    on: {
      "focus": _vm.onFocus
    }
  }), _c("textarea", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.type === "textarea",
      expression: "state.type === 'textarea'"
    }, {
      name: "model",
      rawName: "v-model",
      value: _vm.state.textAreaValue,
      expression: "state.textAreaValue"
    }],
    ref: "popup",
    staticClass: "area popup",
    attrs: {
      "readonly": _vm.readonly,
      "rows": "5"
    },
    domProps: {
      "value": _vm.state.textAreaValue
    },
    on: {
      "blur": _vm.onBlur,
      "input": [function($event) {
        if ($event.target.composing)
          return;
        _vm.$set(_vm.state, "textAreaValue", $event.target.value);
      }, _vm.onInput]
    }
  })]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-text-popup-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/text-popup/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "placeholder", "readonly", "width", "separtor"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-text-popup", {
      "show-auto-width": _vm.state.showAutoWidth
    }],
    style: {
      width: !_vm.state.showAutoWidth && _vm.state.width
    }
  }, [_c("input", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.type === "input",
      expression: "state.type === 'input'"
    }],
    ref: "text",
    staticClass: "area text",
    attrs: {
      "placeholder": _vm.placeholder
    },
    on: {
      "focus": _vm.onFocus
    }
  }), _c("textarea", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.type === "textarea",
      expression: "state.type === 'textarea'"
    }, {
      name: "model",
      rawName: "v-model",
      value: _vm.state.textAreaValue,
      expression: "state.textAreaValue"
    }],
    ref: "popup",
    staticClass: "area popup",
    attrs: {
      "readonly": _vm.readonly,
      "rows": "5"
    },
    domProps: {
      "value": _vm.state.textAreaValue
    },
    on: {
      "blur": _vm.onBlur,
      "input": [function($event) {
        if ($event.target.composing) return;
        _vm.$set(_vm.state, "textAreaValue", $event.target.value);
      }, _vm.onInput]
    }
  })]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
